Marketplace Client Library
==========================

Mozilla is building a Marketplace to bring personalized discovery,
worldwide distribution, and easy payments to the largest platform
for app development: the Web.

This library helps to create Python based sites or apps to communicate
with Marketplace.

You may find and collaborate your time and experience at 
https://github.com/mozilla/Marketplace.Python

Testing
#######

Install test environment::

    pip install mock
    pip install nose

Test::

    nosetests
